aboutsummaryrefslogtreecommitdiffstats
path: root/host/lib/include/uhdlib
diff options
context:
space:
mode:
authorMatthew Crymble <matthew.crymble@ni.com>2020-08-03 14:48:03 -0500
committerAaron Rossetto <aaron.rossetto@ni.com>2020-08-04 15:46:54 -0500
commitc13ba0d21f80fee022f31e13cad0c5b0aa712aaf (patch)
tree12ed62a09f3e2834f7d7a229153ef6dae4871873 /host/lib/include/uhdlib
parentd81816a225979ff26bf1eec454f1caddb94d0ab6 (diff)
downloaduhd-c13ba0d21f80fee022f31e13cad0c5b0aa712aaf.tar.gz
uhd-c13ba0d21f80fee022f31e13cad0c5b0aa712aaf.tar.bz2
uhd-c13ba0d21f80fee022f31e13cad0c5b0aa712aaf.zip
X300: fix for incorrect PCIe buffer size values
added extra args to get PCIe buffer sizes from factory method
Diffstat (limited to 'host/lib/include/uhdlib')
-rw-r--r--host/lib/include/uhdlib/transport/nirio_link.hpp8
1 files changed, 5 insertions, 3 deletions
diff --git a/host/lib/include/uhdlib/transport/nirio_link.hpp b/host/lib/include/uhdlib/transport/nirio_link.hpp
index cf1bb1d75..84d55113d 100644
--- a/host/lib/include/uhdlib/transport/nirio_link.hpp
+++ b/host/lib/include/uhdlib/transport/nirio_link.hpp
@@ -79,13 +79,15 @@ public:
* \param addr a string representing the destination address
* \param port a string representing the destination port
* \param params Values for frame sizes, num frames, and buffer sizes
* \param[out] recv_socket_buff_size Returns the recv socket buffer size
* \param[out] send_socket_buff_size Returns the send socket buffer size
*/
static sptr make(uhd::niusrprio::niusrprio_session::sptr fpga_session,
const uint32_t instance,
const link_params_t& params,
- const uhd::device_addr_t& hints);
+ const uhd::device_addr_t& hints,
+ size_t& recv_buff_size,
+ size_t& send_buff_size);
/*!
* Get the physical adapter ID used for this link
@@ -79,13 +79,15 @@ public:
* \param port a string representing the destination port
* \param params Values for frame sizes, num frames, and buffer sizes
- * \param[out] recv_socket_buff_size Returns the recv socket buffer size
- * \param[out] send_socket_buff_size Returns the send socket buffer size
+ * \param[out] recv_buff_size Returns the recv buffer size
+ * \param[out] send_buff_size Returns the send buffer size
*/
static sptr make(uhd::niusrprio::niusrprio_session::sptr fpga_session,